.. :changelog:

Changelog
=========

1.2.3 (2014-10-10)
------------------

- Unit tests improvements and `PluginsTest` bug fixes
- Custom config directory feature bug fix (``-config`` argument)

1.2.2 (2014-07-03)
------------------

- PEP8'd code (Closes #5)
- Switched to `Apache License, Version 2.0 <https://www.apache.org/licenses/LICENSE-2.0>`_
- Unit test improvement
- Minor feature: custom config directory via ``-c`` or ``-config`` argument.

1.2.1 (2014-06-30)
------------------

- Bug fix (execution via command line. issue #5)

1.2.0 (2014-04-21)
------------------

- Support for `DuckDNS domains update <https://www.duckdns.org/install.jsp>`_

1.1.4 (2013-08-29)
------------------

- Test case improvements
- `Coveralls.io <http://coveralls.io/>`_ support

1.1.3 (2013-07-24)
------------------

- Python 3.3 compatibility

1.1.0 (2013-05-15)
------------------

- Support for `DynDNS Update API <http://dyn.com/support/developers/api/>`_ 
- DDNS auth info storage changed

1.0.1 (2013-05-10)
------------------

- Added flexibility to DNS updater with ``abc.ABCMeta``
- Code organization
- Manual settings file removed (auth info can be stored via command line)

0.1.0 (2013-03-22)
------------------

- Conception
